<?php
/*
Plugin Name: ThemeREX Utilities
Plugin URI: http://themerex.net
Description: Utils for files, directories, post type and taxonomies manipulations
Version: 2.1
Author: ThemeREX
Author URI: http://themerex.net
*/

// Don't load directly
if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}

// Plugin's storage
if ( ! defined( 'TRX_UTILS_PLUGIN_DIR' ) ) define( 'TRX_UTILS_PLUGIN_DIR', plugin_dir_path( __FILE__ ) );
if ( ! defined( 'TRX_UTILS_PLUGIN_URL' ) ) define( 'TRX_UTILS_PLUGIN_URL', plugin_dir_url( __FILE__ ) );
if ( ! defined( 'TRX_UTILS_PLUGIN_BASE' ) ) define( 'TRX_UTILS_PLUGIN_BASE', dirname( plugin_basename( __FILE__ ) ) );

// Current version
if ( ! defined( 'TRX_UTILS_VERSION' ) ) {
	define( 'TRX_UTILS_VERSION', '2.1' );
}

global $TRX_UTILS_STORAGE;
$TRX_UTILS_STORAGE = array(
	// Plugin's location and name
	'plugin_dir' => plugin_dir_path(__FILE__),
	'plugin_url' => plugin_dir_url(__FILE__),
	'plugin_base'=> explode('/', plugin_basename(__FILE__)),
	'plugin_active' => false,
	// Custom post types and taxonomies
	'register_taxonomies' => array(),
	'register_post_types' => array()
);


// Plugin activate hook
if (!function_exists('trx_utils_activate')) {
	register_activation_hook(__FILE__, 'trx_utils_activate');
	function trx_utils_activate() {
		update_option('trx_utils_just_activated', 'yes');
	}
}

// Register theme required types and taxes
if (!function_exists('themerex_require_data')) {	
	function themerex_require_data($type, $name, $args) {
		if ($type == 'taxonomy')
			register_taxonomy($name, $args['post_type'], $args);
		else
			register_post_type($name, $args);
	}
}

// Register theme required shortcodes
if (!function_exists('themerex_require_shortcode')) {	
	function themerex_require_shortcode($name, $callback) {
		add_shortcode($name, $callback);
	}
}

// Return URL to the file in the plugin directory
if (!function_exists('themerex_plugin_get_file_url')) {	
	function themerex_plugin_get_file_url($file) {
		return plugin_dir_url( __FILE__ ) . $file;
	}
}

// Load required styles and scripts in the admin mode
if ( !function_exists( 'trx_utils_load_scripts_admin' ) ) {
    add_action("admin_enqueue_scripts", 'trx_utils_load_scripts_admin');
    function trx_utils_load_scripts_admin($all=false) {
        // Font with icons must be loaded before main stylesheet
        if ($all
            || strpos($_SERVER['REQUEST_URI'], 'post.php')!==false
            || strpos($_SERVER['REQUEST_URI'], 'themes.php')!==false
        ) {
            wp_enqueue_style( 'trx_utils-icons', trx_utils_get_file_url('css/font-icons/css/trx_addons_icons-embedded.css'), array(), null );
        }
        // Fire action to load all other scripts from components
        do_action('trx_utils_action_load_scripts_admin', $all);
    }
}

// Return path to the file in the plugin directory
if (!function_exists('themerex_plugin_get_file_dir')) {	
	function themerex_plugin_get_file_dir($file) {
		return plugin_dir_path( __FILE__ ) . $file;
	}
}

/* Support for meta boxes
--------------------------------------------------- */
if (!function_exists('trx_utils_meta_box_add')) {
    add_action('add_meta_boxes', 'trx_utils_meta_box_add');
    function trx_utils_meta_box_add() {
        // Custom theme-specific meta-boxes
        $boxes = apply_filters('trx_utils_filter_override_options', array());
        if (is_array($boxes)) {
            foreach ($boxes as $box) {
                $box = array_merge(array('id' => '',
                    'title' => '',
                    'callback' => '',
                    'page' => null,        // screen
                    'context' => 'advanced',
                    'priority' => 'default',
                    'callbacks' => null
                ),
                    $box);
                add_meta_box($box['id'], $box['title'], $box['callback'], $box['page'], $box['context'], $box['priority'], $box['callbacks']);
            }
        }
    }
}

// Return text for the Privacy Policy checkbox
if (!function_exists('trx_utils_get_privacy_text')) {
    function trx_utils_get_privacy_text() {
        $page = get_option('wp_page_for_privacy_policy');
        return apply_filters( 'trx_utils_filter_privacy_text', wp_kses_post(
                __( 'I agree that my submitted data is being collected and stored.', 'trx_utils' )
                . ( '' != $page
                    // Translators: Add url to the Privacy Policy page
                    ? ' ' . sprintf(__('For further details on handling user data, see our %s', 'trx_utils'),
                        '<a href="' . esc_url(get_permalink($page)) . '" target="_blank">'
                        . __('Privacy Policy', 'trx_utils')
                        . '</a>')
                    : ''
                )
            )
        );
    }
}

/* LESS compilers
------------------------------------------------------ */

// Compile less-files
if (!function_exists('trx_utils_less_compiler')) {
    function trx_utils_less_compiler($list, $opt) {

        $success = true;

         // Compiler Less
         require_once( plugin_dir_path( __FILE__ ) . 'lib/less/Less.php' );


        foreach($list as $file) {
            if (empty($file) || !file_exists($file)) continue;
            $file_css = substr_replace($file , 'css', strrpos($file , '.') + 1);

            // Check if time of .css file after .less - skip current .less
            if (!empty($opt['check_time']) && file_exists($file_css)) {
                $css_time = filemtime($file_css);
                if ($css_time >= filemtime($file) && ($opt['utils_time']==0 || $css_time > $opt['utils_time'])) continue;
            }

            // Compile current .less file
            try {
                // Create Parser
                    if ($opt['compressed'])
                        $args = array('compress' => true);
                    else {
                        $args = array('compress' => false);
                        if ($opt['map'] != 'no') {
                            $args['sourceMap'] = true;
                            if ($opt['map'] == 'external') {
                                $args['sourceMapWriteTo'] = $file.'.map';
                                $args['sourceMapURL'] = str_replace(
                                        array(get_template_directory(), get_stylesheet_directory()),
                                        array(get_template_directory_uri(), get_stylesheet_directory_uri()),
                                        $file) . '.map';
                            }
                        }
                    }
                    $parser = new Less_Parser($args);

                // Parse main file
                $css = '';

                if ($opt['map'] != 'no' || !empty($opt['parse_files'])) {

                    if ($opt['map'] != 'no' || $opt['compiler'] == 'less') {
                        // Parse main file
                        $parser->parseFile( $file, '');
                        // Parse less utils
                        if (is_array($opt['utils']) && count($opt['utils']) > 0) {
                            foreach($opt['utils'] as $utility) {
                                $parser->parseFile( $utility, '');
                            }
                        }
                        // Parse less vars (from Theme Options)
                        if (!empty($opt['vars'])) {
                            $parser->parse($opt['vars']);
                        }
                        // Get compiled CSS code
                        $css = $parser->getCss();
                        // Reset LESS engine
                        $parser->Reset();
                    } else {
                        $css = $parser->compileFile($file);
                    }

                } else if (($text = file_get_contents($file))!='') {
                    $parts = $opt['separator'] != '' ? explode($opt['separator'], $text) : array($text);
                    for ($i=0; $i<count($parts); $i++) {
                        $text = $parts[$i]
                            . (!empty($opt['utils']) ? $opt['utils'] : '')			// Add less utils
                            . (!empty($opt['vars']) ? $opt['vars'] : '');			// Add less vars (from Theme Options)
                        // Get compiled CSS code
                            $parser->parse($text);
                            $css .= $parser->getCss();
                            $parser->Reset();
                    }
                }
                if ($css) {
                    if ($opt['map']=='no') {
                        // If it main theme style - append CSS after header comments
                        if ($file == get_template_directory(). '/style.less') {
                            // Append to the main Theme Style CSS
                            $theme_css = file_get_contents( get_template_directory() . '/style.css' );
                            $css = substr($theme_css, 0, strpos($theme_css, '*/')+2) . "\n\n" . $css;
                        } else {
                            $css =	"/*"
                                . "\n"
                                . __('Attention! Do not modify this .css-file!', 'trx_utils')
                                . "\n"
                                . __('Please, make all necessary changes in the corresponding .less-file!', 'trx_utils')
                                . "\n"
                                . "*/"
                                . "\n"
                                . '@charset "utf-8";'
                                . "\n\n"
                                . $css;
                        }
                    }
                    // Save compiled CSS
                    file_put_contents( $file_css, $css);
                }
            } catch (Exception $e) {
                if (function_exists('dfl')) dfl($e->getMessage());
                $success = false;
            }
        }
        return $success;
    }
}

// Shortcodes init
if (!function_exists('trx_utils_sc_init')) {
    add_action( 'after_setup_theme', 'trx_utils_sc_init' );
    function trx_utils_sc_init() {
        global $TRX_UTILS_STORAGE;
        if ( !($TRX_UTILS_STORAGE['plugin_active'] = apply_filters('trx_utils_active', $TRX_UTILS_STORAGE['plugin_active'])) ) return;

        // Include shortcodes
        require_once trx_utils_get_file_dir('shortcodes/core.shortcodes.php');
    }
}


// Widgets init
if (!function_exists('trx_utils_setup_widgets')) {
    add_action( 'widgets_init', 'trx_utils_setup_widgets', 9 );
    function trx_utils_setup_widgets() {
        global $TRX_UTILS_STORAGE;
        if ( !($TRX_UTILS_STORAGE['plugin_active'] = apply_filters('trx_utils_active', $TRX_UTILS_STORAGE['plugin_active'])) ) return;

        // Include widgets
        require_once trx_utils_get_file_dir('widgets/advert.php');
        require_once trx_utils_get_file_dir('widgets/calendar.php');
        require_once trx_utils_get_file_dir('widgets/categories.php');
        require_once trx_utils_get_file_dir('widgets/flickr.php');
        require_once trx_utils_get_file_dir('widgets/popular_posts.php');
        require_once trx_utils_get_file_dir('widgets/recent_posts.php');
        require_once trx_utils_get_file_dir('widgets/recent_reviews.php');
        require_once trx_utils_get_file_dir('widgets/socials.php');
        require_once trx_utils_get_file_dir('widgets/top10.php');
        require_once trx_utils_get_file_dir('widgets/twitter.php');
        require_once trx_utils_get_file_dir('widgets/qrcode/qrcode.php');
    }
}

// Show additional fields in the user profile
if (!function_exists('themerex_add_fields_in_user_profile')) {
    function themerex_add_fields_in_user_profile( $user ) {
        ?>
        <h3><?php esc_html_e('User Position', 'kidsplanet'); ?></h3>
        <table class="form-table">
            <tr>
                <th><label for="user_position"><?php esc_html_e('User position', 'kidsplanet'); ?>:</label></th>
                <td><input type="text" name="user_position" id="user_position" size="55" value="<?php echo esc_attr(get_the_author_meta('user_position', $user->ID)); ?>" />
                    <span class="description"><?php esc_html_e('Please, enter your position in the company', 'kidsplanet'); ?></span>
                </td>
            </tr>
        </table>

        <h3><?php esc_html_e('Social links', 'kidsplanet'); ?></h3>
        <table class="form-table">
            <?php
            $socials_type = themerex_get_theme_setting('socials_type');
            $social_list = themerex_get_theme_option('social_icons');
            if (is_array($social_list) && count($social_list) > 0) {
                foreach ($social_list as $soc) {
                    if ($socials_type == 'icons') {
                        $parts = explode('-', $soc['icon'], 2);
                        $sn = isset($parts[1]) ? $parts[1] : $sn;
                    } else {
                        $sn = basename($soc['icon']);
                        $sn = themerex_substr($sn, 0, themerex_strrpos($sn, '.'));
                        if (($pos=themerex_strrpos($sn, '_'))!==false)
                            $sn = themerex_substr($sn, 0, $pos);
                    }
                    if (!empty($sn)) {
                        ?>
                        <tr>
                            <th><label for="user_<?php echo esc_attr($sn); ?>"><?php themerex_show_layout(themerex_strtoproper($sn)); ?>:</label></th>
                            <td><input type="text" name="user_<?php echo esc_attr($sn); ?>" id="user_<?php echo esc_attr($sn); ?>" size="55" value="<?php echo esc_attr(get_the_author_meta('user_'.($sn), $user->ID)); ?>" />
                                <span class="description"><?php echo sprintf(esc_html__('Please, enter your %s link', 'kidsplanet'), themerex_strtoproper($sn)); ?></span>
                            </td>
                        </tr>
                        <?php
                    }
                }
            }
            ?>
        </table>
        <?php
    }
}

// Prepare required styles and scripts for admin mode
if ( ! function_exists( 'trx_utils_admin_prepare_scripts' ) ) {
    add_action( 'admin_head', 'trx_utils_admin_prepare_scripts' );
    function trx_utils_admin_prepare_scripts() {
        ?>
        <script>
            if ( typeof TRX_UTILS_GLOBALS == 'undefined' ) var TRX_UTILS_GLOBALS = {};
            jQuery(document).ready(function() {
                TRX_UTILS_GLOBALS['admin_mode'] = true;
            });
        </script>
        <?php
    }
}

// File functions
if ( file_exists( TRX_UTILS_PLUGIN_DIR . 'includes/plugin.files.php' ) ) {
    require_once TRX_UTILS_PLUGIN_DIR . 'includes/plugin.files.php';
}

// Third-party plugins support
if ( file_exists( TRX_UTILS_PLUGIN_DIR . 'api/api.php' ) ) {
    require_once TRX_UTILS_PLUGIN_DIR . 'api/api.php';
}


// Demo data import/export
if ( file_exists( TRX_UTILS_PLUGIN_DIR . 'importer/importer.php' ) ) {
    require_once TRX_UTILS_PLUGIN_DIR . 'importer/importer.php';
}

if (is_admin()) {
    require_once trx_utils_get_file_dir('tools/emailer/emailer.php');
    require_once trx_utils_get_file_dir('tools/po_composer/po_composer.php');
}

require_once trx_utils_get_file_dir('includes/core.socials.php');
?>